---
title: 'Internet Protocol Is Broken'
sidebar_position: 6
---

The foundational protocols of the internet, TCP/IP (Transmission Control Protocol/Internet Protocol), were created in the 1970s to connect a few academic and military computers. While they served their initial purpose, they were never designed for the complex, global, and interconnected world we live in today. Even IPv6, which addresses some scalability issues, does not solve the fundamental design flaws. 


### How the Internet is Broken Due to TCP/IP Design

The internet, as we know it today, is built on an outdated foundation that was designed for simpler times. Decades ago, TCP/IP was created to connect a handful of computers for research and military purposes. It worked well back then, but it’s no longer enough to handle the complexities of our modern, globally interconnected world. Unless we address its flaws, the internet will struggle to keep up—and could ultimately fail us.

One major issue is that the internet has no way of "remembering" conversations. For example, when you watch a video or make a video call, your device creates a session—a temporary connection with another server. If this session is interrupted, the entire connection breaks, and you must start over. TCP/IP wasn’t designed to manage sessions, making it unreliable for modern apps and services that depend on continuous communication.

Another problem is the internet’s complexity. The way it works involves layers of technology stacked on top of each other—apps, storage systems, networks, and more. These layers often don’t communicate efficiently, wasting resources and making everything slower, more expensive, and harder to fix. This complexity also makes the internet fragile, as small issues can cascade into larger failures.

Security is another area where TCP/IP falls short. It wasn’t designed with cybersecurity in mind, which is why we rely on add-ons like firewalls, VPNs, and encryption. But these tools are essentially patches over a flawed system, and they add even more complexity, making the internet less robust and more vulnerable to attacks.

Modern services and devices have also outgrown the static design of TCP/IP. The system assumes that servers and devices stay in fixed locations, but today’s internet is dynamic. Cloud services, mobile devices, and apps often move across networks. This static model creates inefficiencies and slows down the system.

Adding to the problem is the internet’s dependence on a few centralized services, such as Google, Amazon, and Microsoft. These companies control much of the infrastructure we rely on for communication, storage, and services. If one of them fails—or if access is blocked due to political conflicts—entire regions can lose critical internet functions. This centralization makes the system fragile and leaves users vulnerable.

> The stakes are high. The internet is essential for communication, education, business, and so much more. Yet its foundation is crumbling under modern demands. Without major changes, we’ll see more frequent failures, slower services, and increased vulnerabilities. In extreme cases, parts of the internet could break entirely.

To fix this, we need a smarter, more resilient approach. Decentralized networks can distribute resources and reduce our dependence on a few central providers. Emerging technologies like RINA (Recursive Inter-Network Architecture) offer a simplified, more secure, and more efficient alternative to TCP/IP. These systems are designed to handle the needs of the modern internet, with built-in reliability, smarter communication, and security at their core.

> The bottom line is clear: the internet’s outdated foundation is holding us back. If we want the internet to remain reliable and serve future generations, we must address these issues now. A decentralized, secure, and modernized internet isn’t just a technical upgrade—it’s a necessity for our connected world.


## Tech Brief

The following tech brief is aimed at experts.

### 1. **Lack of Session Management**
- **TCP/IP’s Shortcomings**
  - TCP/IP lacks true session management. A session represents an ongoing communication between two entities (e.g., a user browsing a website). If the connection is interrupted (e.g., due to a network outage or device change), the session is lost, and applications must restart or recover manually.
  - This flaw creates inefficiencies in modern applications that require reliable, continuous communication, such as video calls, gaming, or IoT devices.

- **Why It Matters**
  - Every time a session breaks, applications have to rebuild connections at a higher level (e.g., re-authenticate or restart a video call). This is inefficient and increases complexity, making the internet fragile and less resilient.


---

### 2. **Layer Violations**

- **The Problem**
  - TCP/IP combines different functionalities into a single stack, leading to inefficiencies. For example:
    - Routing decisions happen at the IP layer.
    - Reliable data transfer happens at the TCP layer.
  - However, these layers are not isolated and often interfere with each other, creating unnecessary overhead.

- **Impact**
  - Modern networks require additional layers (e.g., firewalls, VPNs, NATs) to patch these issues, making the architecture increasingly complex and brittle.

---

### 3. **No Built-In Security**
- **TCP/IP Design Flaw**
  - Security was not a priority when TCP/IP was designed. The protocols do not inherently protect against common threats like spoofing, hijacking, or denial of service.
  - IPv6 introduces some improvements, such as built-in IPsec, but these are optional and often not used, leaving the same vulnerabilities.

- **Impact**
  - Every modern application must implement its own security mechanisms (e.g., HTTPS, VPNs), leading to duplicated efforts and inconsistent protections.

---

### 4. **Scalability Issues**

- **IPv4 vs. IPv6**
  - IPv4, with its 32-bit addressing, exhausted available addresses, leading to NAT (Network Address Translation) as a workaround. This introduced complexity and broke the end-to-end connectivity principle of the internet.
  - IPv6, with 128-bit addressing, solves the address exhaustion problem but does not address underlying issues like routing table explosion or inefficiencies in the protocol stack.

- **Routing Problems**
  - The lack of built-in session and naming management makes routing inefficient. Large routing tables and decentralized updates slow down the internet and make it harder to scale.

---

### 5. **No Support for Application-Centric Networking**
- **TCP/IP’s Assumption**
  - The protocol assumes communication happens between fixed endpoints (e.g., IP addresses). Modern applications, however, focus on data and services rather than specific endpoints. For example:
    - Cloud applications may move across data centers.
    - Mobile devices frequently change networks.
  - TCP/IP’s static model is incompatible with this dynamic, service-oriented world.

- **Impact**
  - Workarounds like DNS (Domain Name System) and CDNs (Content Delivery Networks) add layers of complexity, but they’re still built on a flawed foundation.

---

### RINA: A Better Alternative

The **Recursive Inter-Network Architecture (RINA)** proposes a solution to the flaws of TCP/IP by rethinking the internet's architecture. Here’s how RINA addresses these issues[^1]:

1. **Unified Layering**
   - Unlike TCP/IP, which has rigid and distinct layers, RINA uses recursive layers. Each layer provides the same functionalities (e.g., routing, security, session management), simplifying the architecture.

2. **Built-In Session Management**
   - RINA natively supports session management, ensuring continuity and reliability for modern applications, even in the face of interruptions.

3. **Application-Centric Networking:**
   - RINA treats applications as first-class citizens, focusing on the services they need rather than rigid endpoint communication. This aligns with the dynamic nature of modern networks.

4. **Improved Security:**
   - Security is integral to RINA, with mechanisms for authentication, confidentiality, and integrity built into every layer.

5. **Simplified Routing and Scaling:**
   - RINA reduces the size and complexity of routing tables, making the network easier to scale and manage.

[^1]: [RINA Leaflet](https://www.open-root.eu/IMG/pdf/rina-leaflet_20191115_en.pdf)